Struct ockam_command::util::Rpc
source · pub struct Rpc {
pub opts: CommandGlobalOpts,
pub timeout: Option<Duration>,
/* private fields */
}Fields
opts: CommandGlobalOptstimeout: Option<Duration>Implementations
sourceimpl Rpc
impl Rpc
sourcepub async fn embedded(ctx: &Context, opts: &CommandGlobalOpts) -> Result<Rpc>
pub async fn embedded(ctx: &Context, opts: &CommandGlobalOpts) -> Result<Rpc>
Creates a new RPC to send a request to an embedded node.
sourcepub async fn embedded_with_trust_options(
ctx: &Context,
opts: &CommandGlobalOpts,
trust_context_opts: &TrustContextOpts
) -> Result<Rpc>
pub async fn embedded_with_trust_options( ctx: &Context, opts: &CommandGlobalOpts, trust_context_opts: &TrustContextOpts ) -> Result<Rpc>
Creates a new RPC to send a request to an embedded node.
sourcepub async fn embedded_with_vault_and_identity(
ctx: &Context,
opts: &CommandGlobalOpts,
identity: String,
trust_context_opts: &TrustContextOpts
) -> Result<Rpc>
pub async fn embedded_with_vault_and_identity( ctx: &Context, opts: &CommandGlobalOpts, identity: String, trust_context_opts: &TrustContextOpts ) -> Result<Rpc>
Creates a new RPC to send a request to an embedded node.
sourcepub async fn background(
ctx: &Context,
opts: &CommandGlobalOpts,
node_name: &str
) -> Result<Rpc>
pub async fn background( ctx: &Context, opts: &CommandGlobalOpts, node_name: &str ) -> Result<Rpc>
Creates a new RPC to send a request to a running background node.
pub fn node_name(&self) -> &str
pub fn set_node_name(&mut self, node_name: &str) -> &Self
sourcepub fn set_timeout(&mut self, timeout: Duration) -> &mut Self
pub fn set_timeout(&mut self, timeout: Duration) -> &mut Self
Use a timeout for making requests
pub fn set_to(&mut self, to: &MultiAddr) -> Result<&Self>
sourcepub async fn tell<T>(&mut self, req: RequestBuilder<T>) -> Result<()>where
T: Encode<()>,
pub async fn tell<T>(&mut self, req: RequestBuilder<T>) -> Result<()>where T: Encode<()>,
Send a request This method waits for a response status but does not expect a response body If the status is missing or not, we try to parse an error message and return it
sourcepub async fn tell_and_get_status<T>(
&mut self,
req: RequestBuilder<T>
) -> Result<Option<Status>>where
T: Encode<()>,
pub async fn tell_and_get_status<T>( &mut self, req: RequestBuilder<T> ) -> Result<Option<Status>>where T: Encode<()>,
Send a request This method waits for a response status and returns it if available
sourcepub async fn ask<T, R>(&mut self, req: RequestBuilder<T>) -> Result<R>where
T: Encode<()>,
R: for<'b> Decode<'b, ()>,
pub async fn ask<T, R>(&mut self, req: RequestBuilder<T>) -> Result<R>where T: Encode<()>, R: for<'b> Decode<'b, ()>,
Send a request and expects a decodable response This method parses and returns an error message if the request was not successful
sourcepub async fn ask_and_get_reply<T, R>(
&mut self,
req: RequestBuilder<T>
) -> Result<Reply<R>>where
T: Encode<()>,
R: for<'b> Decode<'b, ()>,
pub async fn ask_and_get_reply<T, R>( &mut self, req: RequestBuilder<T> ) -> Result<Reply<R>>where T: Encode<()>, R: for<'b> Decode<'b, ()>,
Send a request and expects either a decodable response or an API error. This method returns an error if the request cannot be sent of if there is any decoding error